@@ -12,21 +12,30 @@
 -- higher-level clients.
 --
 module Network.TLS.Record
-        ( Record(..)
-        , Fragment
-        , fragmentGetBytes
-        , fragmentPlaintext
-        , fragmentCiphertext
-        , recordToRaw
-        , rawToRecord
-        , recordToHeader
-        , Plaintext
-        , Compressed
-        , Ciphertext
-        , engageRecord
-        , disengageRecord
-        ) where
+    ( Record(..)
+    -- * Fragment manipulation types
+    , Fragment
+    , fragmentPlaintext
+    , fragmentCiphertext
+    , recordToRaw
+    , rawToRecord
+    , recordToHeader
+    , Plaintext
+    , Compressed
+    , Ciphertext
+    -- * Engage and disengage from the record layer
+    , engageRecord
+    , disengageRecord
+    -- * State tracking
+    , RecordM
+    , runRecordM
+    , RecordState(..)
+    , newRecordState
+    , getRecordVersion
+    , setRecordIV
+    ) where
 
 import Network.TLS.Record.Types
 import Network.TLS.Record.Engage
 import Network.TLS.Record.Disengage
+import Network.TLS.Record.State
