@@ -11,6 +11,9 @@ module Network.TLS.Types
     , SessionData(..)
     , CipherID
     , CompressionID
+    , Role(..)
+    , invertRole
+    , Direction(..)
     ) where
 
 import Data.ByteString (ByteString)
@@ -26,13 +29,25 @@ type SessionID = ByteString
 
 -- | Session data to resume
 data SessionData = SessionData
-        { sessionVersion :: Version
-        , sessionCipher  :: CipherID
-        , sessionSecret  :: ByteString
-        }
+    { sessionVersion :: Version
+    , sessionCipher  :: CipherID
+    , sessionSecret  :: ByteString
+    } deriving (Show,Eq)
 
 -- | Cipher identification
 type CipherID = Word16
 
 -- | Compression identification
 type CompressionID = Word8
+
+-- | Role
+data Role = ClientRole | ServerRole
+    deriving (Show,Eq)
+
+-- | Direction
+data Direction = Tx | Rx
+    deriving (Show,Eq)
+
+invertRole :: Role -> Role
+invertRole ClientRole = ServerRole
+invertRole ServerRole = ClientRole
